pub struct MetaList {
pub name: Option<Path>,
pub paren: Option<Paren>,
pub list: Punctuated<MetaValue, Comma>,
}Expand description
A meta list.
Use this as the “entrypoint” of your attribute proc macro.
Fields
name: Option<Path>Can be None if this is the root list.
paren: Option<Paren>Can be None if this is the root list.
list: Punctuated<MetaValue, Comma>Implementations